import {Component, Input} from '@angular/core';
import {DevelopmentStore} from "../../../store/DevelopmentStore";
import {AuthStore} from "../../../store/authStore";
import axios from "axios";
import {firstValueFrom} from "rxjs";
import {DatePipe, NgForOf} from "@angular/common";

@Component({
  selector: 'app-loginhistory',
  standalone: true,
  imports: [
    NgForOf,
    DatePipe
  ],
  templateUrl: './loginhistory.component.html',
  styleUrl: './loginhistory.component.scss'
})
export class LoginhistoryComponent {
  @Input() username: string = "";
  loginHistory: any[] = [];

  constructor(private developmentStore: DevelopmentStore, private authStore: AuthStore) {
    this.fetchUserLoginHistory();
  }

  async fetchUserLoginHistory() {
    try {
      const response = await axios({
        method: 'get',
        url: this.developmentStore.getBaseUrl() + 'api/v1/secure/loginhistory',
        headers: {
          'Content-Type': 'application/json',
          'Authorization': 'Bearer ' + await firstValueFrom(this.authStore.token$)
        }
      });
      this.loginHistory = response.data;
      console.log(this.loginHistory)
    } catch (error) {
      console.error(error);
    }
  }

  async deleteLogins() {
    try {
      const response = await axios({
        method: 'delete',
        url: this.developmentStore.getBaseUrl() + 'api/v1/secure/loginhistory',
        headers: {
          'Content-Type': 'application/json',
          'Authorization': 'Bearer ' + await firstValueFrom(this.authStore.token$)
        }
      });
      console.log(response.data);
      this.fetchUserLoginHistory();
    } catch (error) {
      console.error(error);
    }
  }
}
